@@ -1,5 +1,5 @@
 from .web_api import ApiClient
 from .web_api import AsyncApiClient
-from .consumer import Consumer
 from .consumer import AsyncConsumer
-from .consumer import YuanmeiJob
\ No newline at end of file
+from .consumer import YuanmeiJob
+from .consumer import AutoRefreshWindow
\ No newline at end of file
