@@ -1,5 +1,6 @@
 import json, traceback, pretty_errors, asyncio
 import gc
+import sys
 import multiprocessing
 import tkinter as tk
 import queue
@@ -289,12 +290,9 @@ class AsyncConsumer:
                         # 执行用户代码 - 在单独的线程中执行以避免阻塞事件循环
                         code_block = "def run_code():\n"
                         for line in str(app_code).splitlines():
-                            code_block += f"\t{line}\n"
-                        code_block += "run_code()"
+                            code_block += f"    {line}\n"
+                        code_block += "run_code()\n"
                         exec_flag, result = await self.async_run_time_out(code_block, local_vars, max_exec_time)
-                        # 更新job
-                        if exec_flag:
-                            self.currentJob = result["job"]
                         # 检查任务结果
                         if exec_flag and self.currentJob.errorCount == 0:
                             await self.end_job("SUCCESS")
@@ -324,25 +322,25 @@ class AsyncConsumer:
             threading.current_thread().name = thread_id
 
             # 注入通用中断检查函数
-            def should_interrupt(original_line: int):
-                """通用中断检查函数（直接抛出异常）"""
-                if interrupt_event.is_set():
-                    self.print(f"任务中断: 检测到中断请求 (原始行号: {original_line})")
-                    raise RuntimeError(f'任务被强制中断 (原始行号: {original_line})')
-                # 释放GIL，让中断事件能被处理
-                time.sleep(0.001)
-
-            local_vars["should_interrupt"] = should_interrupt
-
-            # 增强代码（单行调用）
-            safe_code = self._enhance_code(code_block)
+            def should_interrupt(frame, event, arg):
+                if event == 'line':
+                    self.print(f"正在执行代码行号: {frame.f_lineno}")
+                    """通用中断检查函数（直接抛出异常）"""
+                    if interrupt_event.is_set():
+                        raise RuntimeError(f'任务被强制中断 (原始行号: {frame.f_lineno})')
+                    # 释放GIL，让中断事件能被处理
+                    time.sleep(0.001)
 
             # 执行增强后的代码
             try:
-                exec(safe_code, local_vars, local_vars)
+                sys.settrace(should_interrupt)
+                exec(code_block, local_vars, local_vars)
                 return True, local_vars
             except Exception as ex:
+                self.print(traceback.format_exc())
                 return False, traceback.format_exc()
+            finally:
+                sys.settrace(None)
 
         try:
             # 执行带超时控制
@@ -364,102 +362,6 @@ class AsyncConsumer:
 
             return False, f"任务执行超时, 超过最大执行时间: {int(max_exec_time)}秒"
 
-    @staticmethod
-    def _is_escaped(line: str, position: int) -> bool:
-        """检查引号是否被转义"""
-        if position <= 0:
-            return False
-        # 计算前面连续反斜杠的数量
-        escape_count = 0
-        pos = position - 1
-        while pos >= 0 and line[pos] == '\\':
-            escape_count += 1
-            pos -= 1
-        # 奇数个反斜杠表示被转义
-        return escape_count % 2 == 1
-
-    def _enhance_code(self, app_code: str) -> str:
-        """终极简化版：单行调用实现中断检查"""
-        lines = app_code.splitlines()
-        new_lines = []
-
-        # 状态跟踪
-        in_string = None
-        in_docstring = None
-        bracket_stack = []
-
-        for i, line in enumerate(lines):
-            stripped = line.strip()
-            current_indent = len(line) - len(line.lstrip())
-            original_line = i + 1  # 人类可读的行号（从1开始）
-
-            # 字符串和文档字符串检测
-            if in_docstring:
-                new_lines.append(line)
-                # 检查文档字符串是否结束
-                if in_docstring in line and line.rstrip().endswith(in_docstring):
-                    in_docstring = None
-                continue
-            elif in_string:
-                new_lines.append(line)
-                # 检查字符串是否结束（考虑转义）
-                if in_string in line and not self._is_escaped(line, line.rfind(in_string)):
-                    in_string = None
-                continue
-            else:
-                # 检测新的文档字符串
-                if stripped.startswith('"""') or stripped.startswith("'''"):
-                    in_docstring = '"""' if stripped.startswith('"""') else "'''"
-                    new_lines.append(line)
-                    continue
-                # 检测新的字符串
-                elif '"' in stripped or "'" in stripped:
-                    # 找到第一个引号
-                    first_quote = min(
-                        (stripped.find('"'), '"') if '"' in stripped else (len(stripped), None),
-                        (stripped.find("'"), "'") if "'" in stripped else (len(stripped), None),
-                        key=lambda x: x[0]
-                    )[1]
-                    if first_quote:
-                        in_string = first_quote
-                        new_lines.append(line)
-                        continue
-
-            # 跳过注释行
-            if stripped.startswith('#') or stripped == '' or in_docstring or in_string:
-                new_lines.append(line)
-                continue
-
-            # 括号平衡检测
-            for char in stripped:
-                if char in '([{':
-                    bracket_stack.append(char)
-                elif char in ')]}':
-                    if bracket_stack:
-                        bracket_stack.pop()
-
-            # 检测RPA操作
-            rpa_keywords = [
-                '.click(', '.dblclick(', '.input(', 'find_by_xpath(',
-                '.clipboard_input', '.hover', '.drag_to', '.upload',
-                '.download', '.process'
-            ]
-            is_rpa_operation = any(keyword in stripped for keyword in rpa_keywords)
-
-            # 安全插入中断检查
-            insert_check = False
-            if is_rpa_operation and not bracket_stack:
-                insert_check = True
-            elif stripped.startswith(('for ', 'while ')) and not bracket_stack:
-                insert_check = True
-
-            # 执行插入（单行调用）
-            new_lines.append(line)
-            if insert_check:
-                new_lines.append(f"{' ' * current_indent}should_interrupt({original_line})")
-
-        return "\n".join(new_lines)
-
     async def _rpa_aware_wait(self, thread_id: str, max_wait: float):
         """RPA感知的线程等待"""
         start_time = time.time()
